@@ -1,5 +1,6 @@
 import sys
 
+import typing
 import pytest
 
 from typing_inspect import (
@@ -14,6 +15,7 @@ from typing import (
     Union, Callable, Optional, TypeVar, Sequence, AnyStr, Mapping,
     MutableMapping, Iterable, Generic, List, Any, Dict, Tuple, NamedTuple,
 )
+from typing import T as typing_T
 
 from mypy_extensions import TypedDict as METypedDict
 from typing_extensions import TypedDict as TETypedDict
@@ -238,6 +240,12 @@ class IsUtilityTestCase(TestCase):
             Literal["v"],
             Literal[1, 2, 3],
         ]
+        if hasattr(typing, "Literal"):
+            samples += [
+                typing.Literal,
+                typing.Literal["v"],
+                typing.Literal[1, 2, 3],
+            ]
         nonsamples = [
             "v",
             (1, 2, 3),
@@ -339,6 +347,8 @@ class GetUtilityTestCase(TestCase):
         self.assertEqual(get_origin(Generic[T]), Generic)
         # Cannot use assertEqual on Py3.5.2.
         self.assertIs(get_origin(Literal[42]), Literal)
+        if hasattr(typing, "Literal"):
+            self.assertIs(get_origin(typing.Literal[42]), typing.Literal)
         if PY39:
             self.assertEqual(get_origin(list[int]), list)
         if GENERIC_TUPLE_PARAMETRIZABLE:
@@ -354,6 +364,10 @@ class GetUtilityTestCase(TestCase):
         self.assertEqual(get_parameters(Union), ())
         if not LEGACY_TYPING:
             self.assertEqual(get_parameters(List[int]), ())
+            if PY39:
+                self.assertEqual(get_parameters(List), ())
+            else:
+                self.assertEqual(get_parameters(List), (typing_T,))
         else:
             # in 3.5.3 a list has no __args__ and instead they are used in __parameters__
             # in 3.5.1 the behaviour is normal again.
@@ -430,6 +444,10 @@ class GetUtilityTestCase(TestCase):
             self.assertEqual(get_args(Literal, evaluate=True), ())
             self.assertEqual(get_args(Literal["value"], evaluate=True), ("value",))
             self.assertEqual(get_args(Literal[1, 2, 3], evaluate=True), (1, 2, 3))
+            if hasattr(typing, "Literal"):
+                self.assertEqual(get_args(typing.Literal, evaluate=True), ())
+                self.assertEqual(get_args(typing.Literal["value"], evaluate=True), ("value",))
+                self.assertEqual(get_args(typing.Literal[1, 2, 3], evaluate=True), (1, 2, 3))
 
         if PY39:
             self.assertEqual(get_args(list[int]), (int,))
